@@ -791,7 +791,7 @@ where
     fn next_address(&self, storage: &dyn Storage) -> Addr {
         // FIXME: quite inefficient if we actually had 100s of contracts
         let count = CONTRACTS
-            .range(storage, None, None, Order::Ascending)
+            .range_raw(storage, None, None, Order::Ascending)
             .count();
         // we make this longer so it is not rejected by tests
         Addr::unchecked(format!("Contract #{}", count.to_string()))
@@ -867,7 +867,7 @@ where
     }
 }
 
-// TODO: replace with code in cw0
+// TODO: replace with code in utils
 
 #[derive(Clone, PartialEq, Message)]
 struct InstantiateResponse {
@@ -877,7 +877,7 @@ struct InstantiateResponse {
     pub data: ::prost::alloc::vec::Vec<u8>,
 }
 
-// TODO: encode helpers in cw0
+// TODO: encode helpers in utils
 fn instantiate_response(data: Option<Binary>, contact_address: &Addr) -> Binary {
     let data = data.unwrap_or_default().to_vec();
     let init_data = InstantiateResponse {
